@@ -2,9 +2,7 @@
 knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>",
-  dev = "ragg_png",
-  dpi = 96,
-  fig.retina = 1,
+  dev = "svg",
   fig.width = 7.2916667,
   fig.asp = 0.618,
   fig.align = "center",
